@@ -11,7 +11,7 @@ import (
 	"strings"
 
 	"github.com/fatih/color"
-	"github.com/jedib0t/go-pretty/table"
+	"github.com/jedib0t/go-pretty/v6/table"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/analyzer/analyzers"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/analyzer/config"
 	"github.com/trufflesecurity/trufflehog/v3/pkg/context"
@@ -152,7 +152,9 @@ type SecretInfo struct {
 func getPermissions(cfg *config.Config, key string) (PermissionsJSON, error) {
 	var permissions PermissionsJSON
 
-	client := analyzers.NewAnalyzeClient(cfg)
+	// POST request is considered as non-safe. Square Post request does not change any state.
+	// We are using unrestricted client to avoid error for non-safe API request.
+	client := analyzers.NewAnalyzeClientUnrestricted(cfg)
 	req, err := http.NewRequest("POST", "https://connect.squareup.com/oauth2/token/status", nil)
 	if err != nil {
 		return permissions, err
@@ -183,7 +185,9 @@ func getPermissions(cfg *config.Config, key string) (PermissionsJSON, error) {
 func getUsers(cfg *config.Config, key string) (TeamJSON, error) {
 	var team TeamJSON
 
-	client := analyzers.NewAnalyzeClient(cfg)
+	// POST request is considered as non-safe. Square Post request does not change any state.
+	// We are using unrestricted client to avoid error for non-safe API request.
+	client := analyzers.NewAnalyzeClientUnrestricted(cfg)
 	req, err := http.NewRequest("POST", "https://connect.squareup.com/v2/team-members/search", nil)
 	if err != nil {
 		return team, err
