@@ -4,13 +4,13 @@ package cache
 // Cache is used to store key/value pairs.
 type Cache[T any] interface {
 	// Set stores the given key/value pair.
-	Set(string, T)
+	Set(key string, val T)
 	// Get returns the value for the given key and a boolean indicating if the key was found.
-	Get(string) (T, bool)
+	Get(key string) (T, bool)
 	// Exists returns true if the given key exists in the cache.
-	Exists(string) bool
+	Exists(key string) bool
 	// Delete the given key from the cache.
-	Delete(string)
+	Delete(key string)
 	// Clear all key/value pairs from the cache.
 	Clear()
 	// Count the number of key/value pairs in the cache.
