@@ -49,16 +49,10 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 
 	resURLMatch := "aha.io"
 	for _, URLmatch := range URLmatches {
-		if len(URLmatch) != 2 {
-			continue
-		}
 		resURLMatch = strings.TrimSpace(URLmatch[1])
 	}
 
 	for _, match := range matches {
-		if len(match) != 2 {
-			continue
-		}
 		resMatch := strings.TrimSpace(match[1])
 
 		s1 := detectors.Result{
