@@ -40,14 +40,8 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 	tokenMatches := keyPat.FindAllStringSubmatch(dataStr, -1)
 
 	for _, match := range matches {
-		if len(match) != 2 {
-			continue
-		}
 		resMatch := strings.TrimSpace(match[1])
 		for _, tokenMatch := range tokenMatches {
-			if len(tokenMatch) != 2 {
-				continue
-			}
 			resToken := strings.TrimSpace(tokenMatch[1])
 
 			s1 := detectors.Result{
