@@ -81,6 +81,12 @@ func (s Scanner) FromData(ctx context.Context, verify bool, data []byte) (result
 				s1.Verified = isVerified
 				s1.ExtraData = extraData
 				s1.SetVerificationError(verificationErr)
+				if s1.Verified {
+					s1.AnalysisInfo = map[string]string{
+						"username": username,
+						"pat":      token,
+					}
+				}
 			}
 
 			results = append(results, s1)
